from setuptools import setup

__project__ = "motivational"
__version__ = "0.0.1"
__description__ = "a Python module to motivate you"
__packages__ = ["motivational"]
__author__ = "Riley Ryan"
__author_email__ = "nezofuvo@maxmail.info"
__classifiers__ = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Education",
    "Programming Language :: Python :: 3",
]
__url__ = "https://github.com/rrfrogtester1/Motivational-Module/"
__keywords__ = ["motivation", "keep going!", "you got it!"]

setup(
    name = __project__,
    version = __version__,
    description = __description__,
    packages = __packages__,
    author = __author__,
    author_email = __author_email__,
    classifiers = __classifiers__,
    url = __url__,
    keywords = __keywords__,
)
